#' plot hydraulics.
#' 
#' @param x an object of class hydraulic
#' @param device, character, defines way of plotting.
#' @param view, vector of character, defines which view shall be plotted. Two options: "height", "discharge".
#' @param ... some extra parameters (unused)
#' @return Nothing
#' 
#' @export

plot.hydraulic = function(
		x,
		device = "display",
		view = c("height", "discharge"),
		...
	)
{
	if (!is.null(x)) {
		return(plot_hydraulic(x, device, view, ...))
	}

	stop(sprintf("No plot.model implementation available for version %s of building", x[["building"]][["general"]][["version"]]))
}

plot_hydraulic = function(
		x,
		device = "display",
		view = c("height", "discharge"),
		selection = NULL,
		...
	)
{
	# Some checks on option
	view = unique(view)
	device = device[[1]]
	
	if (any(is.na(match(device, c("pdf", "png", "display"))))) stop("Bad options for device")
	if (any(is.na(match(view, c("height", "discharge"))))) stop("Bad options for view")
	if (device == "display") view = view[[1]]

	msg = c()
	if ("height" %in% view) {
		msg = c(
			msg, 
			{
				cols = grDevices::rainbow(length(colnames(x[["h"]])[-1]))
				plot(1, type="n", xlim=c(0, max(x[["h"]][, "time"])), 
					ylim=c(0, max(x[["hmax"]]["z", ])), xlab = "time [s]", 
					ylab = "height [m]", main = "Water height in rooms")
				id = 1
				for (room in colnames(x[["h"]])[-1]) {
					graphics::lines(x[["h"]][, "time"], x[["h"]][, room], col = cols[id])
					id = id + 1
				}
				graphics::legend("topright", legend = colnames(x[["h"]])[-1], 
					col = cols, lwd = 2.0, 
					title = "room")
                graphics::grid()
            }
		)
	}
	if ("discharge" %in% view) {
		msg = c(
			msg, 
			{
				cols = grDevices::rainbow(length(colnames(x[["eQ"]])[-1]))
				plot(1, type="n", xlim=c(0, max(x[["eQ"]][, "time"])), 
					ylim=c(min(x$eQ[, colnames(x$eQ)[-1]]), 
					max(x$eQ[, colnames(x$eQ)[-1]])), xlab = "time [s]", 
					ylab = "discharge [m3/s]", main = "Discharge in the openings")
				id = 1
				for (opening in colnames(x[["eQ"]])[-1]) {
					graphics::lines(x[["eQ"]][, "time"], x[["eQ"]][, opening], col = cols[id])
					id = id + 1
				}
				graphics::legend("topright", legend = colnames(x[["eQ"]])[-1], 
					col = cols, lwd = 2.0, 
					title = "opening")
                graphics::grid()
            }
		)
	}
	
	if (device != "display") return(msg)
}	
